# libPythonPro
Modulo para exemplificar a construção de projetos Python no curso Pytools

neste curso é ensinado como contribuir para projetos de odigo aberto

[![Build Status](https://travis-ci.com/EstudosPython/libPythonPro.svg?branch=master)](https://travis-ci.com/EstudosPython/libPythonPro)
[![Updates](https://pyup.io/repos/github/EstudosPython/libPythonPro/shield.svg)](https://pyup.io/repos/github/EstudosPython/libPythonPro/)